/* fileVolume.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef FILEVOLUME_H
#define FILEVOLUME_H

// This is a particular kind of Volume that refers to a mounted
// directory.

#include "volumeBase.h"
#include "dataset.h"

class FileVolume : public VolumeBase {
public:
  FileVolume(const Dataset &data);

  virtual bool exists() const;
  virtual bool can_read_files() const;
  virtual bool can_store_files() const;

  virtual string get_filename(const string &rel_filename);

  virtual string prepare_write_file(const string &basename);
  virtual string close_write_file(const string &full_pathname,
				  const string &basename);

  virtual string store_file(const string &full_pathname, 
			    const string &basename,
			    bool leave_orig);

private:
  virtual void expand_bname();

  string move_file(const string &old_filename, const string &basename,
		   bool leave_orig);
  bool is_bucket_full();
  void increment_bucket();

  static void stat_dir(const string &dirname, int &size_megabytes, 
		       int &num_files);

};

#endif
